import { Encode } from './Encode.js';
import { Table } from './Table.js';

interface LogData {
    readonly data: readonly ReturnType<typeof Encode>[];
    count: number;
    readonly type: "warn" | "info" | "debug" | "error" | "output" | "log";
}
interface TableData {
    readonly data: ReturnType<typeof Table>;
    readonly type: "table";
}
interface GroupData {
    readonly "@key": ReturnType<typeof Encode>;
    readonly "@items": (LogData | TableData | GroupData)[];
}
declare function isGroup(data: any): data is GroupData;
declare function printfArgs<T extends unknown[]>(args: T): unknown[];
declare class DataAPI<Encoded extends boolean = false, Data extends Encoded extends true ? ReturnType<typeof Encode> : unknown = Encoded extends true ? ReturnType<typeof Encode> : unknown> {
    private deepLocation;
    readonly value: (LogData | TableData | GroupData)[];
    private readonly queueGroups;
    private readonly counters;
    private readonly timers;
    private readonly encoded?;
    constructor(encoded?: Encoded, deepLocation?: number);
    private basicMethod;
    log(...data: Data[]): void;
    warn(...data: Data[]): void;
    info(...data: Data[]): void;
    debug(...data: Data[]): void;
    error(...data: Data[]): void;
    table(data: Encoded extends true ? ReturnType<typeof Table> | ReturnType<typeof Encode> : unknown): void;
    private pushOfData;
    group(key?: Data): void;
    groupEnd(key?: Data): void;
    count(key?: unknown): void;
    countReset(key?: unknown): void;
    time(key?: unknown): void;
    timeLog(key?: unknown): void;
    timeEnd(key?: unknown): void;
    clear(): void;
}

export { DataAPI, GroupData, isGroup, printfArgs };
